package com.fuyuanshen.app.service;

import com.fuyuanshen.app.domain.vo.AppUserRoleVo;
import com.fuyuanshen.app.domain.bo.AppUserRoleBo;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * 用户和角色关联Service接口
 *
 * @author Lion Li
 * @date 2025-06-27
 */
public interface IAppUserRoleService {

    /**
     * 查询用户和角色关联
     *
     * @param userId 主键
     * @return 用户和角色关联
     */
    AppUserRoleVo queryById(Long userId);

    /**
     * 分页查询用户和角色关联列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 用户和角色关联分页列表
     */
    TableDataInfo<AppUserRoleVo> queryPageList(AppUserRoleBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的用户和角色关联列表
     *
     * @param bo 查询条件
     * @return 用户和角色关联列表
     */
    List<AppUserRoleVo> queryList(AppUserRoleBo bo);

    /**
     * 新增用户和角色关联
     *
     * @param bo 用户和角色关联
     * @return 是否新增成功
     */
    Boolean insertByBo(AppUserRoleBo bo);

    /**
     * 修改用户和角色关联
     *
     * @param bo 用户和角色关联
     * @return 是否修改成功
     */
    Boolean updateByBo(AppUserRoleBo bo);

    /**
     * 校验并批量删除用户和角色关联信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
